@@ -1,7 +1,7 @@
 package Array::Set;
 
-our $DATE = '2016-09-15'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-09-16'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -181,7 +181,7 @@ sub set_diff {
     } else {
         # fast version, without ib/ic
         my $set1 = shift;
-        my $res;
+        my $res = $set1;
         while (@_) {
             my %set2 = map { $_=>1 } @{ shift @_ };
             $res = [];
@@ -195,11 +195,47 @@ sub set_diff {
 }
 
 sub set_symdiff {
-    _doit('symdiff', @_);
+    my $opts = ref($_[0]) eq 'HASH' ? shift : {};
+    if ($opts->{ignore_case} || $opts->{ignore_blanks}) {
+        _doit('symdiff', $opts, @_);
+    } else {
+        # fast version, without ib/ic
+        my $set1 = shift;
+        my $res = $set1;
+        my %set1;
+        my %set2;
+        while (@_) {
+            my $set2 = shift;
+            $set2{$_} = 1 for @$set2;
+            $res = [];
+            for my $el (@$set1) {
+                push @$res, $el unless $set2{$el};
+            }
+            $set1{$_} = 1 for @$set1;
+            for my $el (@$set2) {
+                push @$res, $el unless $set1{$el};
+            }
+            $set1 = $res;
+        }
+        $res;
+    }
 }
 
 sub set_union {
-    _doit('union', @_);
+    my $opts = ref($_[0]) eq 'HASH' ? shift : {};
+    if ($opts->{ignore_case} || $opts->{ignore_blanks}) {
+        _doit('union', $opts, @_);
+    } else {
+        # fast version, without ib/ic
+        my %mem;
+        my $res = [];
+        while (@_) {
+            for my $el (@{ shift @_ }) {
+                push @$res, $el unless $mem{$el}++;
+            }
+        }
+        $res;
+    }
 }
 
 sub set_intersect {
@@ -209,7 +245,7 @@ sub set_intersect {
     } else {
         # fast version, without ib/ic
         my $set1 = shift;
-        my $res;
+        my $res = $set1;
         while (@_) {
             my %set2 = map { $_=>1 } @{ shift @_ };
             $res = [];
@@ -237,7 +273,7 @@ Array::Set - Perform set operations on arrays
 
 =head1 VERSION
 
-This document describes version 0.04 of Array::Set (from Perl distribution Array-Set), released on 2016-09-15.
+This document describes version 0.05 of Array::Set (from Perl distribution Array-Set), released on 2016-09-16.
 
 =head1 SYNOPSIS
 
@@ -279,11 +315,6 @@ Characteristics and differences with other similar modules:
 
 =back
 
-B<NOTE:> A couple of operations are not optimized yet. More optimizations will
-be done in the future. See some benchmarks in L<Bencher::Scenarios::ArraySet>
-distribution. I also recommend L<Set::Object> (also supports references/objects,
-XS) or simply L<List::MoreUtils> (very popular module, offers XS version).
-
 =head1 FUNCTIONS
 
 All functions are not exported by default, but exportable.
@@ -340,6 +371,8 @@ feature.
 
 =head1 SEE ALSO
 
+See some benchmarks in L<Bencher::Scenarios::ArraySet>.
+
 L<App::setop> to perform set operations on lines of files on the command-line.
 
 L<Array::Utils>, L<Set::Scalar>, L<List::MoreUtils> (C<uniq> for union,
